@@ -3,7 +3,7 @@
  *  Version:  0.2
  *
  *  Description:
- *  This file contains the constants settings for the wmcalc program, 
+ *  This file contains the constants settings for the wmcalc program,
  *  except for the error constants, which are contained in the file wmcalc_err.h
  *
  *  Change History:
@@ -17,16 +17,16 @@
 #define CALC_CMD_SIZE 128
 #define CONFFILENAME  "/.wmcalc"
 #define CONFTEMPFILE  "/tmp/wmcalc.tmp"
-#define CONFIGGLOBAL  "/etc/wmcalc.conf"
+#define CONFIGGLOBAL  CONF"/wmcalc.conf"
 #define VER           0
-#define REL           3
+#define REL           5
 
 #define LMASK         100
 #define MMASK         200
 #define RMASK         300
 
-#define CALCDONE      20        // Anything >= 10 should work
-#define DISPSIZE      10        // Number of characters in display
+#define CALCDONE      20        /* Anything >= 10 should work */
+#define DISPSIZE      10        /* Number of characters in display */
 #define NUM_BUTTONS   21
 #define NUM_MEM_CELLS 10
 
